===================
``matching`` module
===================

.. automodule:: whoosh.matching

Matchers
========

.. autoclass:: Matcher
    :members:
    
.. autoclass:: NullMatcher
.. autoclass:: ListMatcher
.. autoclass:: WrappingMatcher
.. autoclass:: MultiMatcher
.. autoclass:: FilterMatcher
.. autoclass:: BiMatcher
.. autoclass:: AdditiveBiMatcher
.. autoclass:: UnionMatcher
.. autoclass:: DisjunctionMaxMatcher
.. autoclass:: IntersectionMatcher
.. autoclass:: AndNotMatcher
.. autoclass:: InverseMatcher
.. autoclass:: RequireMatcher
.. autoclass:: AndMaybeMatcher
.. autoclass:: ConstantScoreMatcher


Exceptions
==========

.. autoexception:: ReadTooFar
.. autoexception:: NoQualityAvailable
